@@ -1,18 +1,15 @@
 import pytest
 
 from workflows_core.dataset.dataset import Dataset
-from workflows_core.dataset.field import KeyphraseField
 
 
 @pytest.mark.usefixtures("full_dataset")
 class TestKeyphraseCrud:
     def test_crud(self, full_dataset: Dataset):
-        # documents = mock_documents(10)
-        # dataset.insert_documents(documents)
 
-        keyphrase_field = KeyphraseField(dataset=full_dataset, field="sample_1_label")
+        keyphrase_field = full_dataset["_keyphrase_.sample_1_label.default"]
 
-        keyphrase_field.bulk_update_keyphrases(
+        response = keyphrase_field.bulk_update_keyphrases(
             updates=[
                 {
                     "_id": "cat",
@@ -29,8 +26,7 @@ class TestKeyphraseCrud:
                     "goodness_score": 1.1,
                 },
             ],
-            alias="default",
         )
 
-        keyphrase = keyphrase_field.get_keyphrase(alias="default", keyphrase_id="cat")
+        keyphrase = keyphrase_field.get_keyphrase(keyphrase_id="cat")
         assert "cat" == keyphrase["text"]
